==> react-molecule-photo-uploader-1.2.0.tgz: package/lib/ThumbCard.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { BASE_CLASS_NAME } from './config';
var THUMB_CARD_CLASS_NAME = BASE_CLASS_NAME + "-thumbCard";
var IMAGE_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-image";
var ICON_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-iconContainer";
var CONTAINER_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-imageContainer";
var ACTION_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-actions";
var BUTTON_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-button";

var ThumbCard = function ThumbCard(_ref) {
  var _cx;

  var _ref$iconSize = _ref.iconSize,
      iconSize = _ref$iconSize === void 0 ? ATOM_ICON_SIZES.small : _ref$iconSize,
      callbackDeleteItem = _ref.callbackDeleteItem,
      callbackRetryUpload = _ref.callbackRetryUpload,
      callbackRotateItem = _ref.callbackRotateItem,
      deleteIcon = _ref.deleteIcon,
      index = _ref.index,
      image = _ref.image,
      mainPhotoLabel = _ref.mainPhotoLabel,
      rejectPhotosIcon = _ref.rejectPhotosIcon,
      retryIcon = _ref.retryIcon,
      rotateIcon = _ref.rotateIcon;
  var hasErrors = image.hasErrors;
  var counterClass = cx(THUMB_CARD_CLASS_NAME + "-counter", (_cx = {}, _cx[THUMB_CARD_CLASS_NAME + "-mainCounter"] = index === 0, _cx));
  return React.createElement("div", {
    className: THUMB_CARD_CLASS_NAME
  }, React.createElement("div", {
    className: counterClass
  }, index === 0 ? mainPhotoLabel : index + 1), React.createElement("div", {
    className: CONTAINER_THUMB_CARD_CLASS_NAME
  }, hasErrors ? React.createElement("div", {
    className: "" + ICON_THUMB_CARD_CLASS_NAME
  }, React.createElement(AtomIcon, {
    size: ATOM_ICON_SIZES.extraLarge
  }, rejectPhotosIcon)) : React.createElement("img", {
    src: image.preview,
    className: IMAGE_THUMB_CARD_CLASS_NAME
  })), React.createElement("div", {
    className: ACTION_THUMB_CARD_CLASS_NAME
  }, React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick() {
      return callbackDeleteItem(index);
    }
  }, React.createElement(AtomIcon, {
    size: iconSize
  }, deleteIcon)), hasErrors ? React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick(e) {
      return callbackRetryUpload(index);
    }
  }, React.createElement(AtomIcon, {
    size: iconSize
  }, retryIcon)) : React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick(e) {
      return callbackRotateItem(index);
    }
  }, React.createElement(AtomIcon, {
    size: iconSize
  }, rotateIcon))));
};

ThumbCard.displayName = 'ThumbCard';
export default ThumbCard;

==> react-molecule-photo-uploader-1.11.0.tgz: package/lib/ThumbCard.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { BASE_CLASS_NAME } from './config';
var THUMB_CARD_CLASS_NAME = BASE_CLASS_NAME + "-thumbCard";
var IMAGE_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-image";
var ICON_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-iconContainer";
var CONTAINER_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-imageContainer";
var ACTION_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-actions";
var BUTTON_THUMB_CARD_CLASS_NAME = THUMB_CARD_CLASS_NAME + "-button";

var ThumbCard = function ThumbCard(_ref) {
  var _cx, _cx2;

  var _ref$iconSize = _ref.iconSize,
      iconSize = _ref$iconSize === void 0 ? ATOM_ICON_SIZES.small : _ref$iconSize,
      callbackDeleteItem = _ref.callbackDeleteItem,
      callbackRetryUpload = _ref.callbackRetryUpload,
      callbackRotateItem = _ref.callbackRotateItem,
      deleteIcon = _ref.deleteIcon,
      index = _ref.index,
      image = _ref.image,
      mainPhotoLabel = _ref.mainPhotoLabel,
      outputImageAspectRatioDisabled = _ref.outputImageAspectRatioDisabled,
      rejectPhotosIcon = _ref.rejectPhotosIcon,
      retryIcon = _ref.retryIcon,
      rotateIcon = _ref.rotateIcon;
  var hasErrors = image.hasErrors;
  var counterClass = cx(THUMB_CARD_CLASS_NAME + "-counter", (_cx = {}, _cx[THUMB_CARD_CLASS_NAME + "-mainCounter"] = index === 0, _cx));
  var imageThumbClass = cx(IMAGE_THUMB_CARD_CLASS_NAME, (_cx2 = {}, _cx2[IMAGE_THUMB_CARD_CLASS_NAME + "--ratioDisabled"] = outputImageAspectRatioDisabled, _cx2));
  return /*#__PURE__*/React.createElement("div", {
    className: THUMB_CARD_CLASS_NAME
  }, /*#__PURE__*/React.createElement("div", {
    className: counterClass
  }, index === 0 ? mainPhotoLabel : index + 1), /*#__PURE__*/React.createElement("div", {
    className: CONTAINER_THUMB_CARD_CLASS_NAME
  }, hasErrors ? /*#__PURE__*/React.createElement("div", {
    className: "" + ICON_THUMB_CARD_CLASS_NAME
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: ATOM_ICON_SIZES.extraLarge
  }, rejectPhotosIcon)) : /*#__PURE__*/React.createElement("img", {
    src: image.preview,
    className: imageThumbClass
  })), /*#__PURE__*/React.createElement("div", {
    className: ACTION_THUMB_CARD_CLASS_NAME
  }, /*#__PURE__*/React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick() {
      return callbackDeleteItem(index);
    }
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: iconSize
  }, deleteIcon)), hasErrors ? /*#__PURE__*/React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick(e) {
      return callbackRetryUpload(index);
    }
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: iconSize
  }, retryIcon)) : /*#__PURE__*/React.createElement("div", {
    className: BUTTON_THUMB_CARD_CLASS_NAME,
    onClick: function onClick(e) {
      return callbackRotateItem(index);
    }
  }, /*#__PURE__*/React.createElement(AtomIcon, {
    size: iconSize
  }, rotateIcon))));
};

ThumbCard.displayName = 'ThumbCard';
export default ThumbCard;
